#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# vim: fenc=utf-8
# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
#
#

"""
File name: youtube.py
Author: dhilipsiva <dhilipsiva@gmail.com>
Date created: 2016-12-28
"""

DOMAINS = [
    'youtube.com',
    'm.youtube.com',
    'www.youtube.com',
]
